==> lxqt-archiver_0.3.0.orig.tar.xz: lxqt-archiver-0.3.0/README.md <==
# LXQt Archiver

## Overview

A simple & lightweight Qt file archiver.

The core I/O functions are ported from Engrampa (a Gnome File Roller fork).
  * Git revision: c96c85f6d2ff939eeb295e24b699a32262c09151 (2018-06-20)

This is only a front-end (a graphical interface) to archiving programs
like tar and zip. The supported file types are :
  * 7-Zip Compressed File (.7z)
  * WinAce Compressed File (.ace)
  * ALZip Compressed File (.alz)
  * AIX Small Indexed Archive  (.ar)
  * ARJ Compressed Archive (.arj)
  * Cabinet File (.cab)
  * UNIX CPIO Archive (.cpio)
  * Debian Linux Package (.deb) [Read-only mode]
  * ISO-9660 CD Disc Image (.iso) [Read-only mode]
  * Java Archive (.jar)
  * Java Enterprise archive (.ear)
  * Java Web Archive (.war)
  * LHA Archive (.lzh, .lha)
  * WinRAR Compressed Archive (.rar)
  * RAR Archived Comic Book (.cbr)
  * RPM Linux Package (.rpm) [Read-only mode]
  * Tape Archive File:
        * uncompressed (.tar)
    or compressed with:
        * gzip (.tar.gz , .tgz)
        * bzip (.tar.bz , .tbz)
        * bzip2 (.tar.bz2 , .tbz2)
        * compress (.tar.Z , .taz)
        * lrzip (.tar.lrz , .tlrz)
        * lzip (.tar.lz , .tlz)
        * lzop (.tar.lzo , .tzo)
        * 7zip (.tar.7z)
        * xz (.tar.xz)
  * Stuffit Archives (.bin, .sit)
  * ZIP Archive (.zip)
  * ZIP Archived Comic Book (.cbz)
  * ZOO Compressed Archive File (.zoo)
  * Single files compressed with gzip, bzip, bzip2, compress, lrzip, lzip,
    lzop, rzip, xz.



### Translation

Translations can be done in [LXQt-Weblate](https://translate.lxqt-project.org/projects/lxqt-desktop/lxqt-archiver/)

<a href="https://translate.lxqt-project.org/projects/lxqt-desktop/lxqt-archiver/">
<img src="https://translate.lxqt-project.org/widgets/lxqt-desktop/-/lxqt-archiver/multi-auto.svg" alt="Translation status" />
</a>

==> lxqt-archiver-1.3.0.tar.xz: lxqt-archiver-1.3.0/README.md <==
# LXQt Archiver

## Overview

A simple & lightweight Qt file archiver.

The core I/O functions are ported from Engrampa (a Gnome File Roller fork).
  * Git revision: c96c85f6d2ff939eeb295e24b699a32262c09151 (2018-06-20)

This is only a front-end (a graphical interface) to archiving programs
like tar and zip. The supported file types are :
  * 7-Zip Compressed File (.7z)
  * WinAce Compressed File (.ace)
  * ALZip Compressed File (.alz)
  * AIX Small Indexed Archive  (.ar)
  * ARJ Compressed Archive (.arj)
  * Cabinet File (.cab)
  * UNIX CPIO Archive (.cpio)
  * Debian Linux Package (.deb) [Read-only mode]
  * ISO-9660 CD Disc Image (.iso) [Read-only mode]
  * Java Archive (.jar)
  * Java Enterprise archive (.ear)
  * Java Web Archive (.war)
  * LHA Archive (.lzh, .lha)
  * WinRAR Compressed Archive (.rar)
  * RAR Archived Comic Book (.cbr)
  * RPM Linux Package (.rpm) [Read-only mode]
  * Tape Archive File:
        * uncompressed (.tar)
    or compressed with:
        * gzip (.tar.gz , .tgz)
        * bzip (.tar.bz , .tbz)
        * bzip2 (.tar.bz2 , .tbz2)
        * compress (.tar.Z , .taz)
        * lrzip (.tar.lrz , .tlrz)
        * lzip (.tar.lz , .tlz)
        * lzop (.tar.lzo , .tzo)
        * 7zip (.tar.7z)
        * xz (.tar.xz)
  * Stuffit Archives (.bin, .sit)
  * ZIP Archive (.zip)
  * ZIP Archived Comic Book (.cbz)
  * ZOO Compressed Archive File (.zoo)
  * Single files compressed with gzip, bzip, bzip2, compress, lrzip, lzip,
    lzop, rzip, xz.

### Binary packages

Official binary packages are provided by most major Linux and BSD distributions. 
Just use your package manager to search for string `lxqt-archiver`.

### Translation

Translations can be done in [LXQt-Weblate](https://translate.lxqt-project.org/projects/lxqt-desktop/lxqt-archiver/)

<a href="https://translate.lxqt-project.org/projects/lxqt-desktop/lxqt-archiver/">
<img src="https://translate.lxqt-project.org/widgets/lxqt-desktop/-/lxqt-archiver/multi-auto.svg" alt="Translation status" />
</a>
